3.5.4. pypago.data.loaddata_area_t — PyPAGO 1.0.1 documentation

# 3.5.4. pypago.data.loaddata_area_t

`pypago.data.` `loaddata_area_t`(model_areas, filename, dictvarname)

  Extracts the model output from model T-grid points and interpolates them on section west and north faces. The extracted data are added to the input file:

      import pypago.data

      filenameT = 'g88_2000_00_gridT.nc'
      dictvarname = {'vect':'votemper, 'vecs':vosaline'}
      pypago.data.loaddata_sec_T('data.pygo', filenameT, dictvarname)

  Parameters: | structfile (str) – The name of the .pygo file where the list of `pypago.sections.Gridsection` objects are stored.

  Changed in version 20120515: JD PAGO WHOI